package com.fs.company.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.company.domain.CompanyDomainBindUser;
import com.fs.company.param.CompanyDomainBindUserParam;
import com.fs.company.vo.CompanyDomainBindUserVo;

/**
 * 企业域名分配中间表Service接口
 * 
 * @author fs
 * @date 2025-06-19
 */
public interface ICompanyDomainBindUserService extends IService<CompanyDomainBindUser>{
    /**
     * 查询企业域名分配中间表
     * 
     * @param id 企业域名分配中间表主键
     * @return 企业域名分配中间表
     */
    CompanyDomainBindUser selectCompanyDomainBindUserById(Long id);

    /**
     * 查询企业域名分配中间表列表
     * 
     * @param companyDomainBindUser 企业域名分配中间表
     * @return 企业域名分配中间表集合
     */
    List<CompanyDomainBindUserVo> selectCompanyDomainBindUserList(CompanyDomainBindUserParam companyDomainBindUser);

    /**
     * 新增企业域名分配中间表
     * 
     * @param companyDomainBindUser 企业域名分配中间表
     * @return 结果
     */
    int insertCompanyDomainBindUser(CompanyDomainBindUser companyDomainBindUser);

    /**
     * 修改企业域名分配中间表
     * 
     * @param companyDomainBindUser 企业域名分配中间表
     * @return 结果
     */
    int updateCompanyDomainBindUser(CompanyDomainBindUser companyDomainBindUser);

    /**
     * 批量删除企业域名分配中间表
     * 
     * @param ids 需要删除的企业域名分配中间表主键集合
     * @return 结果
     */
    int deleteCompanyDomainBindUserByIds(Long[] ids);

    /**
     * 删除企业域名分配中间表信息
     * 
     * @param id 企业域名分配中间表主键
     * @return 结果
     */
    int deleteCompanyDomainBindUserById(Long id);
}
